@@ -62,7 +62,7 @@ impl RawEncoder for EUCJPEncoder {
                     let ptr = index::jis0208::backward(ch as u32);
                     if ptr == 0xffff {
                         return (i, Some(CodecError {
-                            upto: j as int, cause: "unrepresentable character".into_maybe_owned()
+                            upto: j as int, cause: "unrepresentable character".into_cow()
                         }));
                     } else {
                         let lead = ptr / 94 + 0xa1;
@@ -453,7 +453,7 @@ impl RawEncoder for Windows31JEncoder {
                     let ptr = index::jis0208::backward_remapped(ch as u32);
                     if ptr == 0xffff {
                         return (i, Some(CodecError {
-                            upto: j as int, cause: "unrepresentable character".into_maybe_owned(),
+                            upto: j as int, cause: "unrepresentable character".into_cow(),
                         }));
                     } else {
                         let lead = ptr / 188;
@@ -771,7 +771,7 @@ impl RawEncoder for ISO2022JPEncoder {
                     if ptr == 0xffff {
                         self.st = st; // do NOT reset the state!
                         return (i, Some(CodecError {
-                            upto: j as int, cause: "unrepresentable character".into_maybe_owned()
+                            upto: j as int, cause: "unrepresentable character".into_cow()
                         }));
                     } else {
                         ensure_Lead!();
